=========
miniBlog
=========

.. image:: https://img.shields.io/pypi/l/django-miniblog
   :alt: Apache-2.0
   :target: https://gitlab.com/pascalpepe/django-miniblog/blob/main/LICENSE

.. image:: https://img.shields.io/pypi/v/django-miniblog
   :alt: PyPI
   :target: https://pypi.org/project/django-miniblog/

.. image:: https://img.shields.io/pypi/pyversions/django-miniblog
   :alt: Python
   :target: https://pypi.org/project/django-miniblog/

.. image:: https://img.shields.io/pypi/djversions/django-miniblog?label=django
   :alt: Django
   :target: https://pypi.org/project/django-miniblog/

.. image:: https://gitlab.com/pascalpepe/django-miniblog/badges/main/pipeline.svg
   :alt: Pipeline
   :target: https://gitlab.com/pascalpepe/django-miniblog/-/pipelines

miniBlog is a Django application for managing a simple blog.

:Home: https://www.pascalpepe.com/en/projects/django-miniblog/
:Documentation: https://pascalpepe.gitlab.io/django-miniblog
:Source code: https://gitlab.com/pascalpepe/django-miniblog
:Issue tracker: https://gitlab.com/pascalpepe/django-miniblog/issues


Status
======

This project is still in its initial development stage. Anything may change at
any time.


Supported versions of Python and Django
=======================================

======= ===================================
Django  Python
======= ===================================
2.2 LTS 3.5, 3.6, 3.7, 3.8 (added in 2.2.8)
------- -----------------------------------
3.1     3.6, 3.7, 3.8
======= ===================================


Documentation
=============

The documentation of this project is available at
https://pascalpepe.gitlab.io/django-miniblog.

- `Getting started <https://pascalpepe.gitlab.io/django-miniblog/getting-started.html>`_
- `Module references <https://pascalpepe.gitlab.io/django-miniblog/references/index.html>`_
- `Release notes <https://pascalpepe.gitlab.io/django-miniblog/releases/index.html>`_


Licenses
========

Source code
-----------

This project is licensed under the `Apache License 2.0 <http://www.apache.org/licenses/LICENSE-2.0>`_.

Documentation
-------------

The documentation of this project is licensed under a `Creative Commons Attribution-ShareAlike 4.0 International License <https://creativecommons.org/licenses/by-sa/4.0/>`_.

Code samples and snippets found in the documentation are licensed under
the Apache License 2.0, same as the project source code.
